==> aspose-words-cloud-20.5.0.tar.gz: aspose-words-cloud-20.5.0/asposewordscloud/models/list_levels.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="ListLevels.py">
#   Copyright (c) 2019 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class ListLevels(object):
    """Represents a single document list.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'list_level': 'list[ListLevel]'
    }

    attribute_map = {
        'link': 'link',
        'list_level': 'ListLevel'
    }

    def __init__(self, link=None, list_level=None):  # noqa: E501
        """ListLevels - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._list_level = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if list_level is not None:
            self.list_level = list_level

    @property
    def link(self):
        """Gets the link of this ListLevels.  # noqa: E501

        Gets or sets link.  # noqa: E501

        :return: The link of this ListLevels.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this ListLevels.

        Gets or sets link.  # noqa: E501

        :param link: The link of this ListLevels.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link
    @property
    def list_level(self):
        """Gets the list_level of this ListLevels.  # noqa: E501

        Gets or sets the collection of list levels for this list.  # noqa: E501

        :return: The list_level of this ListLevels.  # noqa: E501
        :rtype: list[ListLevel]
        """
        return self._list_level

    @list_level.setter
    def list_level(self, list_level):
        """Sets the list_level of this ListLevels.

        Gets or sets the collection of list levels for this list.  # noqa: E501

        :param list_level: The list_level of this ListLevels.  # noqa: E501
        :type: list[ListLevel]
        """
        self._list_level = list_level
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLevels):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> aspose-words-cloud-20.6.0.tar.gz: aspose-words-cloud-20.6.0/asposewordscloud/models/list_levels.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="list_levels.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class ListLevels(object):
    """Represents a single document list.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'list_level': 'list[ListLevel]'
    }

    attribute_map = {
        'link': 'Link',
        'list_level': 'ListLevel'
    }

    def __init__(self, link=None, list_level=None):  # noqa: E501
        """ListLevels - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._list_level = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if list_level is not None:
            self.list_level = list_level

    @property
    def link(self):
        """Gets the link of this ListLevels.  # noqa: E501

        Gets or sets link to the document.  # noqa: E501

        :return: The link of this ListLevels.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this ListLevels.

        Gets or sets link to the document.  # noqa: E501

        :param link: The link of this ListLevels.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def list_level(self):
        """Gets the list_level of this ListLevels.  # noqa: E501

        Gets or sets the collection of list levels for this list.  # noqa: E501

        :return: The list_level of this ListLevels.  # noqa: E501
        :rtype: list[ListLevel]
        """
        return self._list_level

    @list_level.setter
    def list_level(self, list_level):
        """Sets the list_level of this ListLevels.

        Gets or sets the collection of list levels for this list.  # noqa: E501

        :param list_level: The list_level of this ListLevels.  # noqa: E501
        :type: list[ListLevel]
        """
        self._list_level = list_level


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLevels):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
